@@ -68,7 +68,7 @@ class ProxyServer(StreamServer):
 
          # make SSL work:
         if self.ssl_enabled:
-            self._handle = self.wrapsocket_and_handle
+            self._handle = self.wrap_socket_and_handle
         else:
             self._handle = self.handle
 
@@ -94,6 +94,10 @@ class ProxyServer(StreamServer):
         super(ProxyServer, self).stop_accepting()
 
     def start_accepting(self):
+        self.refresh_name() 
+        super(ProxyServer, self).start_accepting()
+
+    def serve_forever(self):
         if hasattr(self.script, "load"):
             self.route = self.script.load()
         else:
@@ -109,15 +113,18 @@ class ProxyServer(StreamServer):
         except AttributeError:
             pass 
 
-
-        self.refresh_name() 
-        super(ProxyServer, self).start_accepting()
+        super(ProxyServer, self).serve_forever()
 
     def handle(self, socket, address):
         """ handle the connection """
         conn = ClientConnection(socket, address, self)
         conn.handle()
 
+    def wrap_socket_and_handle(self, client_socket, address):
+        # used in case of ssl sockets
+        ssl_socket = self.wrap_socket(client_socket, **self.ssl_args)
+        return self.handle(ssl_socket, address)
+
 def tcp_listener(address, backlog=None):
     backlog = backlog or 128
 
